pub async fn connect<P: AsRef<Path>>(
path: P,
) -> Result<Framed<UnixStream, PacketCodec>>Expand description
Connect to a local IPC socket
On Unix systems, this uses Unix Domain Sockets On Windows, this falls back to TCP localhost connections
pub async fn connect<P: AsRef<Path>>(
path: P,
) -> Result<Framed<UnixStream, PacketCodec>>Connect to a local IPC socket
On Unix systems, this uses Unix Domain Sockets On Windows, this falls back to TCP localhost connections